# eric7.Plugins.VcsPlugins.vcsMercurial.ShelveExtension.HgUnshelveDataDialog

Module implementing a dialog to enter the data for an unshelve operation.

### Global Attributes

None

### Classes

HgUnshelveDataDialog | Class implementing a dialog to enter the data for an unshelve operation.

### Functions

None

## HgUnshelveDataDialog

Class implementing a dialog to enter the data for an unshelve operation.

### Derived from

QDialog, Ui_HgUnshelveDataDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgUnshelveDataDialog | Constructor
getData | Public method to get the user data.

### Static Methods

None

#### HgUnshelveDataDialog (Constructor)

HgUnshelveDataDialog(shelveNames, shelveName="", parent=None)

Constructor

shelveNames
  list of available shelves (list of string)
shelveName
  name of the shelve to restore (string)
parent
  reference to the parent widget (QWidget)

#### HgUnshelveDataDialog.getData

getData()

Public method to get the user data.

Return:
  tuple containing the name (string) and a flag indicating to keep the shelved change (boolean)

Up